@@ -91,7 +91,7 @@ class Base64Source(menus.ListPageSource):
         author: discord.abc.User,
         entries: list[str],
         per_page: int = 10,
-    ):  # noqa
+    ):
         super().__init__(entries=entries, per_page=per_page)
         self.cog = cog
         self.author = author
@@ -171,9 +171,10 @@ class PlaylistListSource(menus.ListPageSource):
                     _("ID: {id}").format(id=playlist.id),
                     _("Tracks: {num}").format(num=len(playlist.tracks)),
                     _("Author: {name}").format(name=author_name),
-                    _("Scope: {scope}\n").format(scope=scope_name) if not is_same else "\n",
+                    "\n" if is_same else _("Scope: {scope}\n").format(scope=scope_name),
                 )
             )
+
             plist += f"`{i}.` {playlist_info}"
 
         embed = await self.cog.lavalink.construct_embed(
